limabean.adapter.bean-queries


balancesclj

(balances beans args)

Build balances from beans, optionally further filtered.

Custom directives may be passed in after the filters using :directives.

Build balances from `beans`, optionally further filtered.

Custom directives may be passed in after the filters using :directives.
sourceraw docstring

income-statementclj

(income-statement beans args)

Build balances from beans, optionally further filtered.

Custom directives may be passed in after the filters using :directives.

Build balances from `beans`, optionally further filtered.

Custom directives may be passed in after the filters using :directives.
sourceraw docstring

inventoryclj

(inventory beans args)

Build inventory from beans after applying filters, if any.

Custom directives may be passed in after the filters using :directives.

Build inventory from `beans` after applying filters, if any.

Custom directives may be passed in after the filters using :directives.
sourceraw docstring

journalclj

(journal beans args)

Build a journal of postings from beans with running balance.

Custom directives may be passed in after the filters using :directives.

Build a journal of postings from `beans` with running balance.

Custom directives may be passed in after the filters using :directives.
sourceraw docstring

rollupclj

(rollup inv)

Build a rollup for the primary currency from an inventory.

To build for a different currency, simply filter by that currency, e.g

(rollup (inventory (f/cur "CHF")))
Build a rollup for the primary currency from an inventory.

To build for a different currency, simply filter by that currency, e.g
```
(rollup (inventory (f/cur "CHF")))
```
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries