(print-causes e)Prints the message of e and all its causes
Prints the message of e and all its causes
(print-exception e)Print exception to err according to what it is.
Print exception to *err* according to what it is.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |