limabean.adapter.plugins


has-specified-plugins?clj

(has-specified-plugins? resolved-plugins sel)

Return whether there are plugins of the given kind to run

Return whether there are plugins of the given kind to run
sourceraw docstring

resolve-symbolsclj

(resolve-symbols plugins options)

Resolve plugin symbols, returning as an updated map

Resolve plugin symbols, returning as an updated map
sourceraw docstring

run-plugins-of-kindclj

(run-plugins-of-kind directives resolved-plugins sel)

Run the non-error plugins selected by sel, one of :raw-xf, :booked-xf

Run the non-error plugins selected by `sel`, one of `:raw-xf,` `:booked-xf`
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries