(book pod)(book pod directives)Book directives, or parsed directives by default
Book directives, or parsed directives by default
(create-synthetic-spans pod requests)Create spans for synthetic sources, e.g. the output of plugins
Create spans for synthetic sources, e.g. the output of plugins
(invoke pod method)(invoke pod method params)Invoke a remote procedure call, with the method and params
Invoke a remote procedure call, with the method and params
(ok-or-throw result)Either unwrap an ok result, or throw
Either unwrap an ok result, or throw
(resolve-span pod span)Resolve a span in terms of original sources
Resolve a span in terms of original sources
(start beancount-path)Run limabean-pod serve and remain attached
Run limabean-pod serve and remain attached
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |