limabean.core.filters

Functions to filter directives and postings according to their various fields, conventionally aliased to f.

Example:

(show (inventory (f/date> 2025)))

In general these filters reject anything missing the target field.

Functions to filter directives and postings according to their various fields, conventionally aliased to `f`.

Example:
```
(show (inventory (f/date> 2025)))
```

In general these filters reject anything missing the target field.
raw docstring

limabean.core.inventory

Functions to build and query an inventory.

Functions to build and query an inventory.
raw docstring

limabean.core.journal

Functions to build and query journal.

A journal is a date-ordered list of postings with running balance (across all accounts). To restrict the balance to fewer accounts, pre-filter by account.

Functions to build and query journal.

A journal is a date-ordered list of postings with running balance (across all accounts).
To restrict the balance to fewer accounts, pre-filter by account.
raw docstring

limabean.core.registry

Functions to build and query registry.

The registry is build from directives and options, and contains for example, booking method for each account, and currencies in order of frequency of usage.

Functions to build and query registry.

The registry is build from directives and options, and contains for example, booking method for each account, and currencies in order of frequency of usage.
raw docstring

limabean.core.rollup

Functions to build and query rollup.

A rollup is built from an inventory, for a single currency, and comprises individual balances as well as sub-totals and totals per parent account.

Functions to build and query rollup.

A rollup is built from an inventory, for a single currency, and comprises individual balances as well as sub-totals and totals per parent account.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries