limabean.core.cell


align-leftclj

(align-left s)

Convert string to left-aligned cell

Convert string to left-aligned cell
sourceraw docstring

anchoredclj

(anchored s i)

Anchor a string at i

Anchor a string at i
sourceraw docstring

cellcljmultimethod

Prepare as a cell for tabulation, or ? if unsupported

Prepare as a cell for tabulation, or ? if unsupported
sourceraw docstring

EMPTYclj

source

markclj

(mark m type)

Mark a map as a cell of specified type, for the cell multimethod.

Mark a map as a cell of specified type, for the cell multimethod.
sourceraw docstring

real-keysclj

(real-keys m)
source

rowclj

(row cells gutter)

Convert a row to cells with gutter

Convert a row to cells with gutter
sourceraw docstring

SPACE-MEDIUMclj

source

SPACE-MINORclj

source

stackclj

(stack cells)

A stack of cells

A stack of cells
sourceraw docstring

unmarkclj

(unmark m)

Unmark a previously marked cell

Unmark a previously marked cell
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries