limabean.core.inventory

Functions to build and query an inventory.

Functions to build and query an inventory.
raw docstring

accumulateclj

(accumulate inv p)

Accumulate a position into an inventory according to its booking method.

Position attributes are :units, :cur, and :cost.

Accumulate a position into an inventory according to its booking method.

Position attributes are `:units`, `:cur`, and `:cost`.
sourceraw docstring

accumulatorclj

(accumulator booking)

Create an inventory accumulator with given booking method.

Create an inventory accumulator with given booking method.
sourceraw docstring

buildclj

(build postings acc-booking-fn)

Cumulate postings into inventory according to booking method.

acc-booking-fn is a function which returns the booking method for an account.

Cumulate postings into inventory according to booking method.

`acc-booking-fn` is a function which returns the booking method for an account.
sourceraw docstring

cur-freqclj

(cur-freq inv)

Return map of frequency of currency use by currency.

Return map of frequency of currency use by currency.
sourceraw docstring

positionsclj

(positions inv)

Return the current balance of an inventory accumulator as a list of positions.

Return the current balance of an inventory accumulator as a list of positions.
sourceraw docstring

positions->unitsclj

(positions->units ps)

Return positions collapsed down to units only with no costs.

Return positions collapsed down to units only with no costs.
sourceraw docstring

positions->units-ofclj

(positions->units-of ps cur)

Return positions collapsed down to units only of the specified currency with no costs, or zero if none for that currency.

Return positions collapsed down to units only of the specified currency with no costs, or zero if none for that currency.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries