Clojure only.

limabean.core.registry

Functions to build and query registry.

The registry is build from directives and options, and contains for example, booking method for each account, and currencies in order of frequency of usage.

Functions to build and query registry.

The registry is build from directives and options, and contains for example, booking method for each account, and currencies in order of frequency of usage.
raw docstring

acc-bookingclj

(acc-booking reg acc)

Lookup the booking method for an account in the registry.

Lookup the booking method for an account in the registry.
sourceraw docstring

buildclj

(build directives options)

Build the registry for given directives and options.

Build the registry for given `directives` and `options`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries