Clojure only.

limabean.core.rollup

Functions to build and query rollup.

A rollup is built from an inventory, for a single currency, and comprises individual balances as well as sub-totals and totals per parent account.

Functions to build and query rollup.

A rollup is built from an inventory, for a single currency, and comprises individual balances as well as sub-totals and totals per parent account.
raw docstring

buildclj

(build inv cur)

Build rollup in a single currency from an inventory.

Build rollup in a single currency from an inventory.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries