Clojure only.

limabean.core.xf

Transducers.

Transducers.
raw docstring

all-ofclj

(all-of filters)

Transducer to filter items selected by all filters

Transducer to filter items selected by all filters
sourceraw docstring

postingsclj

(postings)

Transducer to extract postings from directives, with date et al from the parent transaction.

Transducer to extract postings from directives, with date et al from the parent transaction.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries