Clojure only.

limabean.plugin


dct-error!cljmacro

(dct-error! dct message)

Annotate a directive with the given error message, appending to any other errors.

Annotate a directive with the given error message, appending to any other errors.
sourceraw docstring

error!cljmacrodeprecated

(error! dct message)

Deprecated macro to throw an exception when a plugin detects a bad directive.

Deprecated macro to throw an exception when a plugin detects a bad directive.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries