limabean.user

Top-level limabean functions for use from the REPL.

Top-level limabean functions for use from the REPL.
raw docstring

*beans*clj

An aggregate of the elements which were used in deriving the directives for the current beanfile.

Useful in case of failed plugins, for inspecting partial state.

An aggregate of the elements which were used in deriving the directives for the current beanfile.

Useful in case of failed plugins, for inspecting partial state.
sourceraw docstring

*directives*clj

Vector of all directives form the beanfile after running plugins.

Vector of all directives form the beanfile after running plugins.
sourceraw docstring

*options*clj

Map of options from the beanfile.

Map of options from the beanfile.
sourceraw docstring

*registry*clj

Map of attributes derived from directives and options, e.g. booking method for account.

Map of attributes derived from directives and options, e.g. booking method for account.
sourceraw docstring

balancesclj

(balances & filters)

Build balances from *beans*, optionally further filtered.

Build balances from `*beans*`, optionally further filtered.
sourceraw docstring

income-statementclj

(income-statement & filters)

Build balances from *beans*, optionally further filtered.

Build balances from `*beans*`, optionally further filtered.
sourceraw docstring

inventoryclj

(inventory & filters)

Build inventory from *beans* after applying filters, if any.

Build inventory from `*beans*` after applying filters, if any.
sourceraw docstring

journalclj

(journal & filters)

Build a journal of postings from *beans* with running balance.

Build a journal of postings from `*beans*` with running balance.
sourceraw docstring

load-beanfileclj

(load-beanfile path)
source

rollupclj

(rollup inv)

Build a rollup for the primary currency from an inventory.

To build for a different currency, simply filter by that currency, e.g

(rollup (inventory (f/cur "CHF")))
Build a rollup for the primary currency from an inventory.

To build for a different currency, simply filter by that currency, e.g
```
(rollup (inventory (f/cur "CHF")))
```
sourceraw docstring

showclj

(show x)

Convert x to a cell and tabulate it.

Convert `x` to a cell and tabulate it.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries