Clojure only.

limabean.util


map-ifclj

(map-if pred f c1 c2)

Map over collections c1 and c2, where elements are combined using f if (pred e1) returns true, else simply an element from c1

Map over collections `c1` and `c2`, where elements are combined using f if (pred e1) returns true, else simply an element from c1
sourceraw docstring

map-nclj

(map-n num-f f c1 c2)

Map over collections c1 and c2, where elements are combined using f which takes (num-f e1) elements from c2, else simply an element from c1

Map over collections `c1` and `c2`, where elements are combined using f which takes (num-f e1) elements from c2, else simply an element from c1
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries