(balances beans args)Build balances from beans, optionally further filtered.
Custom directives may be passed in after the filters using :directives.
Build balances from `beans`, optionally further filtered. Custom directives may be passed in after the filters using :directives.
(income-statement beans args)Build balances from beans, optionally further filtered.
Custom directives may be passed in after the filters using :directives.
Build balances from `beans`, optionally further filtered. Custom directives may be passed in after the filters using :directives.
(inventory beans args)Build inventory from beans after applying filters, if any.
Custom directives may be passed in after the filters using :directives.
Build inventory from `beans` after applying filters, if any. Custom directives may be passed in after the filters using :directives.
(journal beans args)Build a journal of postings from beans with running balance.
Custom directives may be passed in after the filters using :directives.
Build a journal of postings from `beans` with running balance. Custom directives may be passed in after the filters using :directives.
(rollup inv)Build a rollup for the primary currency from an inventory.
To build for a different currency, simply filter by that currency, e.g
(rollup (inventory (f/cur "CHF")))
Build a rollup for the primary currency from an inventory. To build for a different currency, simply filter by that currency, e.g ``` (rollup (inventory (f/cur "CHF"))) ```
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |