(has-specified-plugins? resolved-plugins sel)Return whether there are plugins of the given kind to run
Return whether there are plugins of the given kind to run
(resolve-symbols plugins options)Resolve plugin symbols, returning as an updated map
Resolve plugin symbols, returning as an updated map
(run-plugins-of-kind directives resolved-plugins sel)Run the non-error plugins selected by sel, one of :raw-xf, :booked-xf
Run the non-error plugins selected by `sel`, one of `:raw-xf,` `:booked-xf`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |