limabean.adapter.pod


bookclj

(book pod)
(book pod directives)

Book directives, or parsed directives by default

Book directives, or parsed directives by default
sourceraw docstring

create-synthetic-spansclj

(create-synthetic-spans pod requests)

Create spans for synthetic sources, e.g. the output of plugins

Create spans for synthetic sources, e.g. the output of plugins
sourceraw docstring

directivesclj

(directives pod)

Return parsed directives

Return parsed directives
sourceraw docstring

ERROR-INDEXED-REPORTclj

source

ERROR-REPORTclj

source

format-errorsclj

(format-errors pod errors)

Format errors

Format errors
sourceraw docstring

format-warningsclj

(format-warnings pod warnings)

Format warnings

Format warnings
sourceraw docstring

invokeclj

(invoke pod method)
(invoke pod method params)

Invoke a remote procedure call, with the method and params

Invoke a remote procedure call, with the method and params
sourceraw docstring

ok-or-throwclj

(ok-or-throw result)

Either unwrap an ok result, or throw

Either unwrap an ok result, or throw
sourceraw docstring

optionsclj

(options pod)

Return parsed options

Return parsed options
sourceraw docstring

pluginsclj

(plugins pod)

Return parsed plugins

Return parsed plugins
sourceraw docstring

resolve-spanclj

(resolve-span pod span)

Resolve a span in terms of original sources

Resolve a span in terms of original sources
sourceraw docstring

startclj

(start beancount-path)

Run limabean-pod serve and remain attached

Run limabean-pod serve and remain attached
sourceraw docstring

statusclj

(status pod)

Return pod status

Return pod status
sourceraw docstring

stopclj

(stop pod)

Stop the limabean-pod

Stop the limabean-pod
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries