(align-left s)Convert string to left-aligned cell
Convert string to left-aligned cell
Prepare as a cell for tabulation, or ? if unsupported
Prepare as a cell for tabulation, or ? if unsupported
(mark m type)Mark a map as a cell of specified type, for the cell multimethod.
Mark a map as a cell of specified type, for the cell multimethod.
(row cells gutter)Convert a row to cells with gutter
Convert a row to cells with gutter
(unmark m)Unmark a previously marked cell
Unmark a previously marked cell
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |