(directive->str dct)Convert directive to string
Convert directive to string
(elements-xf element-builder)Transducer to produce elements from directives, to facilitate building synthetic spans.
Except for transactions, each directive results in a single string, its human-readable representation.
Transactions result in strings for the header and each posting separately.
element-builder is a function taking the directive and string, and returning the element
Transducer to produce elements from directives, to facilitate building synthetic spans. Except for transactions, each directive results in a single string, its human-readable representation. Transactions result in strings for the header and each posting separately. `element-builder` is a function taking the directive and string, and returning the element
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |