Functions to build and query registry.
The registry is build from directives and options, and contains for example, booking method for each account, and currencies in order of frequency of usage.
Functions to build and query registry. The registry is build from directives and options, and contains for example, booking method for each account, and currencies in order of frequency of usage.
(acc-booking reg acc)Lookup the booking method for an account in the registry.
Lookup the booking method for an account in the registry.
(build directives options)Build the registry for given directives and options.
Build the registry for given `directives` and `options`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |