Functions to build and query rollup.
A rollup is built from an inventory, for a single currency, and comprises individual balances as well as sub-totals and totals per parent account.
Functions to build and query rollup. A rollup is built from an inventory, for a single currency, and comprises individual balances as well as sub-totals and totals per parent account.
(build inv cur)Build rollup in a single currency from an inventory.
Build rollup in a single currency from an inventory.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |