Transducers.
Transducers.
(all-of filters)Transducer to filter items selected by all filters
Transducer to filter items selected by all filters
(postings)Transducer to extract postings from directives, with date et al from the parent transaction.
Transducer to extract postings from directives, with date et al from the parent transaction.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |