(dct-error! dct message)Annotate a directive with the given error message, appending to any other errors.
Annotate a directive with the given error message, appending to any other errors.
(error! dct message)Deprecated macro to throw an exception when a plugin detects a bad directive.
Deprecated macro to throw an exception when a plugin detects a bad directive.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |