Top-level limabean functions for use from the REPL.
Top-level limabean functions for use from the REPL.
An aggregate of the elements which were used in deriving the directives for the current beanfile.
Useful in case of failed plugins, for inspecting partial state.
An aggregate of the elements which were used in deriving the directives for the current beanfile. Useful in case of failed plugins, for inspecting partial state.
Vector of all directives form the beanfile after running plugins.
Vector of all directives form the beanfile after running plugins.
Map of attributes derived from directives and options, e.g. booking method for account.
Map of attributes derived from directives and options, e.g. booking method for account.
(balances & filters)Build balances from *beans*, optionally further filtered.
Build balances from `*beans*`, optionally further filtered.
(income-statement & filters)Build balances from *beans*, optionally further filtered.
Build balances from `*beans*`, optionally further filtered.
(inventory & filters)Build inventory from *beans* after applying filters, if any.
Build inventory from `*beans*` after applying filters, if any.
(journal & filters)Build a journal of postings from *beans* with running balance.
Build a journal of postings from `*beans*` with running balance.
(rollup inv)Build a rollup for the primary currency from an inventory.
To build for a different currency, simply filter by that currency, e.g
(rollup (inventory (f/cur "CHF")))
Build a rollup for the primary currency from an inventory. To build for a different currency, simply filter by that currency, e.g ``` (rollup (inventory (f/cur "CHF"))) ```
(show x)Convert x to a cell and tabulate it.
Convert `x` to a cell and tabulate it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |